@@ -58,8 +58,10 @@ def job_launch():
 
 @click.command(name="sequence_classification")
 @click.option("--name", required=True, help="Job name")
-@click.option("--model_id", required=True, help="Model ID")
-@click.option("--dataset_id", required=True, help="Dataset ID")
+@click.option("--model_id", required=True, help="Model ID or S3 path")
+@click.option("--dataset_id", required=True, help="Dataset ID or S3 path")
+@click.option("--aws_access_key_id", required=False, help="aws_access_key_id if you specify a S3 path for the model or dataset")
+@click.option("--aws_secret_access_key", required=False, help="aws_secret_access_key if you specify a S3 path for the model or dataset")
 @click.option(
     "--optimization_criteria",
     required=True,
@@ -75,16 +77,24 @@ def job_launch_sequence_classification(
     name,
     model_id,
     dataset_id,
+    aws_access_key_id,
+    aws_secret_access_key,
     optimization_criteria,
     sentence1_column,
     sentence2_column,
     labels_column,
     max_seq_length,
 ):
-    model = Models.get_model(model_id)
-    assert model is not None, "Model ID does not exist"
-    dataset = Datasets.get_dataset(dataset_id)
-    assert dataset is not None, "Dataset ID does not exist"
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        model_id = Models.get_model(model_id).get_id()
+    
+    assert model_id is not None, "Model ID does not exist"
+    
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        dataset_id = Datasets.get_dataset(dataset_id).get_id()
+        
+    assert dataset_id is not None, "Dataset ID does not exist"
+    
     assert optimization_criteria in [
         "latency",
         "lossless",
@@ -99,18 +109,22 @@ def job_launch_sequence_classification(
 
     job = Job(name=name)
     job.launch_auto(
-        model=model,
-        dataset=dataset,
+        model_id=model_id,
+        dataset_id=dataset_id,
         task_type=task_type,
         optimization_criteria=OptimizationCriteria.LATENCY,
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
     )
     EventLogger.log_event("jobs_sequence_classification")
 
 
 @click.command(name="question_answering")
 @click.option("--name", required=True, help="Job name")
-@click.option("--model_id", required=True, help="Model ID")
-@click.option("--dataset_id", required=True, help="Dataset ID")
+@click.option("--model_id", required=True, help="Model ID or S3 path")
+@click.option("--dataset_id", required=True, help="Dataset ID or S3 path")
+@click.option("--aws_access_key_id", required=False, help="aws_access_key_id if you specify a S3 path for the model or dataset")
+@click.option("--aws_secret_access_key", required=False, help="aws_secret_access_key if you specify a S3 path for the model or dataset")
 @click.option(
     "--optimization_criteria",
     required=True,
@@ -127,6 +141,8 @@ def job_launch_question_answering(
     name,
     model_id,
     dataset_id,
+    aws_access_key_id,
+    aws_secret_access_key,
     optimization_criteria,
     question_column,
     answer_column,
@@ -134,10 +150,16 @@ def job_launch_question_answering(
     max_seq_length,
     stride,
 ):
-    model = Models.get_model(model_id)
-    assert model is not None, "Model ID does not exist"
-    dataset = Datasets.get_dataset(dataset_id)
-    assert dataset is not None, "Dataset ID does not exist"
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        model_id = Models.get_model(model_id).get_id()
+    
+    assert model_id is not None, "Model ID does not exist"
+    
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        dataset_id = Datasets.get_dataset(dataset_id).get_id()
+        
+    assert dataset_id is not None, "Dataset ID does not exist"
+    
     assert optimization_criteria in [
         "latency",
         "lossless",
@@ -153,18 +175,22 @@ def job_launch_question_answering(
 
     job = Job(name=name)
     job.launch_auto(
-        model=model,
-        dataset=dataset,
+        model_id=model_id,
+        dataset_id=dataset_id,
         task_type=task_type,
         optimization_criteria=OptimizationCriteria.LATENCY,
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
     )
     EventLogger.log_event("jobs_question_answering")
 
 
 @click.command(name="summarization")
 @click.option("--name", required=True, help="Job name")
-@click.option("--model_id", required=True, help="Model ID")
-@click.option("--dataset_id", required=True, help="Dataset ID")
+@click.option("--model_id", required=True, help="Model ID or S3 path")
+@click.option("--dataset_id", required=True, help="Dataset ID or S3 path")
+@click.option("--aws_access_key_id", required=False, help="aws_access_key_id if you specify a S3 path for the model or dataset")
+@click.option("--aws_secret_access_key", required=False, help="aws_secret_access_key if you specify a S3 path for the model or dataset")
 @click.option(
     "--optimization_criteria",
     required=True,
@@ -197,6 +223,8 @@ def job_launch_summarization(
     name,
     model_id,
     dataset_id,
+    aws_access_key_id,
+    aws_secret_access_key,
     optimization_criteria,
     text_column,
     summary_column,
@@ -209,10 +237,16 @@ def job_launch_summarization(
     source_prefix,
     forced_bos_token,
 ):
-    model = Models.get_model(model_id)
-    assert model is not None, "Model ID does not exist"
-    dataset = Datasets.get_dataset(dataset_id)
-    assert dataset is not None, "Dataset ID does not exist"
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        model_id = Models.get_model(model_id).get_id()
+    
+    assert model_id is not None, "Model ID does not exist"
+    
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        dataset_id = Datasets.get_dataset(dataset_id).get_id()
+        
+    assert dataset_id is not None, "Dataset ID does not exist"
+    
     assert optimization_criteria in [
         "latency",
         "lossless",
@@ -233,18 +267,22 @@ def job_launch_summarization(
 
     job = Job(name=name)
     job.launch_auto(
-        model=model,
-        dataset=dataset,
+        model_id=model_id,
+        dataset_id=dataset_id,
         task_type=task_type,
         optimization_criteria=OptimizationCriteria.LATENCY,
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
     )
     EventLogger.log_event("jobs_question_summarization")
 
 
 @click.command(name="translation")
 @click.option("--name", required=True, help="Job name")
-@click.option("--model_id", required=True, help="Model ID")
-@click.option("--dataset_id", required=True, help="Dataset ID")
+@click.option("--model_id", required=True, help="Model ID or S3 path")
+@click.option("--dataset_id", required=True, help="Dataset ID or S3 path")
+@click.option("--aws_access_key_id", required=False, help="aws_access_key_id if you specify a S3 path for the model or dataset")
+@click.option("--aws_secret_access_key", required=False, help="aws_secret_access_key if you specify a S3 path for the model or dataset")
 @click.option(
     "--optimization_criteria",
     required=True,
@@ -283,6 +321,8 @@ def job_launch_translation(
     name,
     model_id,
     dataset_id,
+    aws_access_key_id,
+    aws_secret_access_key,
     optimization_criteria,
     translation_column,
     src_lang,
@@ -295,10 +335,16 @@ def job_launch_translation(
     source_prefix,
     forced_bos_token,
 ):
-    model = Models.get_model(model_id)
-    assert model is not None, "Model ID does not exist"
-    dataset = Datasets.get_dataset(dataset_id)
-    assert dataset is not None, "Dataset ID does not exist"
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        model_id = Models.get_model(model_id).get_id()
+    
+    assert model_id is not None, "Model ID does not exist"
+    
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        dataset_id = Datasets.get_dataset(dataset_id).get_id()
+        
+    assert dataset_id is not None, "Dataset ID does not exist"
+    
     assert optimization_criteria in [
         "latency",
         "lossless",
@@ -319,18 +365,22 @@ def job_launch_translation(
 
     job = Job(name=name)
     job.launch_auto(
-        model=model,
-        dataset=dataset,
+        model_id=model_id,
+        dataset_id=dataset_id,
         task_type=task_type,
         optimization_criteria=OptimizationCriteria.LATENCY,
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
     )
     EventLogger.log_event("jobs_translation")
 
 
 @click.command(name="token_classification")
 @click.option("--name", required=True, help="Job name")
-@click.option("--model_id", required=True, help="Model ID")
-@click.option("--dataset_id", required=True, help="Dataset ID")
+@click.option("--model_id", required=True, help="Model ID or S3 path")
+@click.option("--dataset_id", required=True, help="Dataset ID or S3 path")
+@click.option("--aws_access_key_id", required=False, help="aws_access_key_id if you specify a S3 path for the model or dataset")
+@click.option("--aws_secret_access_key", required=False, help="aws_secret_access_key if you specify a S3 path for the model or dataset")
 @click.option(
     "--optimization_criteria",
     required=True,
@@ -349,6 +399,8 @@ def job_launch_token_classification(
     name,
     model_id,
     dataset_id,
+    aws_access_key_id,
+    aws_secret_access_key,
     optimization_criteria,
     tokens_column,
     domains_column,
@@ -356,10 +408,16 @@ def job_launch_token_classification(
     max_seq_length,
     label_all_tokens,
 ):
-    model = Models.get_model(model_id)
-    assert model is not None, "Model ID does not exist"
-    dataset = Datasets.get_dataset(dataset_id)
-    assert dataset is not None, "Dataset ID does not exist"
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        model_id = Models.get_model(model_id).get_id()
+    
+    assert model_id is not None, "Model ID does not exist"
+    
+    if aws_access_key_id is not None and aws_secret_access_key is not None:
+        dataset_id = Datasets.get_dataset(dataset_id).get_id()
+        
+    assert dataset_id is not None, "Dataset ID does not exist"
+    
     assert optimization_criteria in [
         "latency",
         "lossless",
@@ -375,10 +433,12 @@ def job_launch_token_classification(
 
     job = Job(name=name)
     job.launch_auto(
-        model=model,
-        dataset=dataset,
+        model_id=model_id,
+        dataset_id=dataset_id,
         task_type=task_type,
         optimization_criteria=OptimizationCriteria.LATENCY,
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
     )
     EventLogger.log_event("jobs_token_classification")
 
