@@ -6,18 +6,19 @@ import datetime
 
 def parse_date(date_string):
     source_fmt = "%Y-%m-%dT%H:%M:%S.%fZ"
-    return str(datetime.datetime.strptime(date_string, source_fmt).replace(microsecond=0))
-    
+    return str(
+        datetime.datetime.strptime(date_string, source_fmt).replace(microsecond=0)
+    )
 
-def print_table(columns, list_of_list_values):    
+
+def print_table(columns, list_of_list_values):
     table = Table(title=None)
-    
+
     for column in columns:
         table.add_column(column)
-    
+
     for values in list_of_list_values:
         table.add_row(*values)
-            
-        
+
     console = Console()
-    console.print(table)
\ No newline at end of file
+    console.print(table)
